@@ -21,7 +21,7 @@ sub new{
 sub export{
     my( $self ) = @_;
 
-    system("ffmpeg -i \'$self->{_inputFile}\' -y -pass 1 -an -vcodec libx264 -vpre slowfirstpass -vpre ipod320 -b 1500kb -bt 1000kb -threads 0 -s 480x320 -aspect 16:9 -f ipod \'$self->{_outputFile}$self->{_extension}\' && ffmpeg -i \'$self->{_inputFile}\' -y -pass 2 -vcodec libx264 -vpre hq -vpre ipod320 -b 1500kb -bt 1000kb -threads 0 -s 480x320 -acodec libfaac -ab 192kb -ac 2 -aspect 16:9 -f ipod \'$self->{_outputFile}$self->{_extension}\'");
+    system("avconv -i \'$self->{_inputFile}\' -y -pass 1 -an -vcodec libx264 -pre slow_firstpass -pre ipod320 -b 1500k -bt 1000k -threads 0 -s 480x320 -aspect 16:9 -f ipod \'$self->{_outputFile}$self->{_extension}\' && avconv -i \'$self->{_inputFile}\' -y -pass 2 -vcodec libx264 -pre medium -pre ipod320 -b 1500k -bt 1000k -threads 0 -s 480x320 -acodec libfaac -ab 192kb -ac 2 -aspect 16:9 -f ipod \'$self->{_outputFile}$self->{_extension}\'");
 
 }
 
