@@ -13,9 +13,4 @@ sub generateContentType{
     }
 }
 
-sub  creeksideDB{
-    DBI->connect('DBI:mysql:creeksidestaging:127.0.0.1', 'creekside', 'cr4wd4ds',
-                {RaiseError => 1, AutoCommit => 1});
-}
-
-1;
\ No newline at end of file
+1;
